@@ -110,7 +110,7 @@ void ReportGenerator::createDocument( ReportFormat format, const QString& docID,
 
     if( mProcess && mProcess->state() != QProcess::NotRunning ) {
         qDebug() << "===> WRN: Process still running, try again later.";
-        emit failure(i18n("Document generation process is still running."), "");
+        emit failure(i18n("The document generation process is still running."), QString());
         return;
     }
 
@@ -165,7 +165,7 @@ void ReportGenerator::slotAddresseeFound( const QString&, const KContacts::Addre
 
     QFileInfo fi(_tmplFile);
     if (!fi.exists()) {
-        emit failure(i18n("Template file is not accessible."), "");
+        emit failure(i18n("The temporary file %1 is not accessible.", _tmplFile), QString());
         return;
     }
     const QString ext = fi.completeSuffix();
@@ -198,7 +198,7 @@ void ReportGenerator::slotAddresseeFound( const QString&, const KContacts::Addre
     const QString tempFile = saveToTempFile(expanded);
 
     if (tempFile.isEmpty()) {
-        emit failure(i18n("Saving to temporar file failed."), "");
+        emit failure(i18n("Saving to temporary file failed."), QString());
         delete converter;
         return;
     }
@@ -332,7 +332,7 @@ void ReportGenerator::slotConverterError(PDFConverter::ConvError err)
          errMsg = i18n("No converter error.");
         break;
     case PDFConverter::ConvError::TrmlToolFail:
-        errMsg = i18n("The ReportLab based converter script can not be executed.");
+        errMsg = i18n("The ReportLab based converter script cannot be executed.");
         break;
     case PDFConverter::ConvError::UnknownError:
         errMsg = i18n("An unknown error happened.");
@@ -344,10 +344,10 @@ void ReportGenerator::slotConverterError(PDFConverter::ConvError err)
         errMsg = i18n("The PyPDF2 python module is not installed.");
         break;
     case PDFConverter::ConvError::SourceFileFail:
-        errMsg = i18n("The source file can not be read.");
+        errMsg = i18n("The source file cannot be read.");
         break;
     case PDFConverter::ConvError::TargetFileError:
-        errMsg = i18n("The target can not be opened to write.");
+        errMsg = i18n("The target cannot be opened to write.");
         break;
     case PDFConverter::ConvError::TargetFileMissing:
         errMsg = i18n("The target file does not exist.");
@@ -375,16 +375,19 @@ QString ReportGenerator::findTemplateFile( const QString& type )
     const QString tmplFile = dType.templateFile();
 
     if ( tmplFile.isEmpty() ) {
-        emit failure(i18n("There is not template defined for %1.").arg(dType.name()), "");
+        emit failure(i18n("There is not template defined for %1.", dType.name()),
+                     i18n("Make sure to define a template file in the settings dialog."));
     } else {
-        // check if file exists
+        // a few file checks
         QFileInfo fi(tmplFile);
         if (!fi.isFile()) {
-            emit failure(i18n("The template file %1 for document type %2 does not exist.").arg(tmplFile).arg(dType.name()), "");
+            emit failure(i18n("The template file %1 for document type %2 is not a file.", tmplFile, dType.name()),
+                         i18n("Make sure to pick a readable template file in the settings dialog"));
             return QString();
         }
         if (!fi.isReadable()) {
-            emit failure(i18n("The template file %1 for document type %2 can not be read.").arg(tmplFile).arg(dType.name()), "");
+            emit failure(i18n("The template file %1 for document type %2 can not be read.", tmplFile, dType.name()),
+                         i18n("Make sure the template file has proper file permissions."));
             return QString();
         }
     }
